@@ -14,7 +14,14 @@ test_that("Differential uprate factor preserves order", {
 
 test_that("Wage growth is higher for extreme salaries", {
   skip_on_cran()
-  skip_if_not_installed("taxstats") 
+  skip_if_not_installed("taxstats")
+  skip_if_not_installed("dplyr")
+  library(taxstats)
+  library(dplyr)
+  skip_if_not(exists("get_sample_files_all"))
+  try(sample_files_all <- get_sample_files_all())
+  skip_if_not(exists("sample_files_all"))
+  
   extreme_tile <- sample(c(1:20, 80:100), size = 1)
   
   # Not comparing 20 with 79 or 21 with 80
@@ -97,6 +104,7 @@ test_that("Less than 0.1% of individuals move more than one percentile over 10 y
 test_that("differential wage inflator is mean-preserving", {
   skip_if_not_installed("taxstats") 
   skip_on_cran()
+  library(magrittr)
   salaries_1314 <- sample_file_1314$Sw_amt
 
   salaries_1314_vanilla <- wage_inflator(salaries_1314, from_fy = "2013-14", to_fy = "2015-16")
@@ -104,7 +112,7 @@ test_that("differential wage inflator is mean-preserving", {
   
   t_test <- 
     stats::t.test(salaries_1314_vanilla, salaries_1314_differe, conf.level = 0.66) %>%
-    broom::tidy(.)
+    use_series("p.value")
 
-  expect_gt(t_test$p.value, 0.05)
+  expect_gt(t_test, 0.05)
 })
