@@ -4,7 +4,8 @@ test_that("No NAs for sample_files_all", {
   skip_if_not_installed("taxstats") 
   skip_on_cran()
   skip_on_appveyor()
-  invisible(sample_files_all)
+  library(taxstats)
+  sample_files_all <- get_sample_files_all()
   expect_false(anyNA(income_tax(sample_files_all[["Taxable_Income"]], 
                                 fy.year = sample_files_all[["fy.year"]], 
                                 .dots.ATO = sample_files_all)))
